@@ -325,7 +325,8 @@ class SmarterApi:
         if not user_id:
             return_message = self.send_message(message=SmarterMessage(), port="#user")
             user_id = return_message.get("user", {}).get("id")
-        existing_data = self.get_user_data(user_id=user_id, data_type_filter=data_type_id)[0][0]
+        existing_data = self.get_user_data(user_id=user_id, data_type_filter=data_type_id)
+        existing_data = existing_data[0][0] if existing_data else None
         updated_data = merge_data(old_data=existing_data, new_data=data)
         try:
             string_data = json.dumps(updated_data)
